@@ -1,11 +1,11 @@
 gaussian.dissimilarityCAR <-
-function(formula, beta=NULL, phi=NULL, nu2=NULL, tau2=NULL, rho=NULL, fix.rho=FALSE, alpha=NULL, W, Z, burnin=0, n.sample=1000, thin=1, blocksize.phi=10, prior.mean.beta=NULL, prior.var.beta=NULL, prior.max.nu2=NULL, prior.max.tau2=NULL, prior.max.alpha=NULL)
+function(formula, data=NULL, beta=NULL, phi=NULL, nu2=NULL, tau2=NULL, rho=NULL, fix.rho=FALSE, alpha=NULL, W, Z, burnin=0, n.sample=1000, thin=1, blocksize.phi=10, prior.mean.beta=NULL, prior.var.beta=NULL, prior.max.nu2=NULL, prior.max.tau2=NULL, prior.max.alpha=NULL)
 {
 ##############################################
 #### Format the arguments and check for errors
 ##############################################
 #### Overall formula object
-frame <- try(suppressWarnings(model.frame(formula, na.action=na.pass)), silent=TRUE)
+frame <- try(suppressWarnings(model.frame(formula, data=data, na.action=na.pass)), silent=TRUE)
 if(class(frame)=="try-error") stop("the formula inputted contains an error, e.g the variables may be different lengths.", call.=FALSE)
 
 
@@ -656,12 +656,19 @@ data.temp.beta <- data.var.beta %*% t(X.standardised)
 ## Acceptance rates
      if(fix.rho)
      {
-     accept.alpha <- 100 * accept[1] / accept[2]    
+     accept.alpha <- 100 * accept[1] / accept[2]
+     accept.final <- c(100, 100, 100, 100, accept.alpha)
+     names(accept.final) <- c("beta", "phi", "nu2", "tau2", "alpha")
      }else
      {
      accept.alpha <- 100 * accept.all[1] / accept.all[2]
+     accept.rho <- 100 * accept.all[3] / accept.all[4] 
+     accept.final <- c(100, 100, 100, 100, accept.alpha, accept.rho)
+     names(accept.final) <- c("beta", "phi", "nu2", "tau2", "alpha", "rho")
      }
 
+        
+     
 ## Deviance information criterion (DIC)
 median.beta <- apply(samples.beta, 2, median)
 median.phi <- apply(samples.phi, 2, median)
@@ -829,61 +836,24 @@ W.border.prob <- array(NA, c(n,n))
 
 
 
-#### Print a summary of the results to the screen
-	if(fix.rho)
-	{
-	cat("\n#################\n")
-	cat("#### Model fitted\n")
-	cat("#################\n\n")
-	cat("Likelihood model - Gaussian (identity link function) \n")
-	cat("Random effects model - Localised CAR binary weights\n")
-	cat("Regression equation - ")
-	print(formula)
-	cat("Dissimilarity metrics - ")
-	cat(rownames(summary.alpha), sep=", ")
 
-	cat("\n\n############\n")
-	cat("#### Results\n")
-	cat("############\n\n")
-
-	cat("Posterior quantiles and acceptance rates\n\n")
-	print(summary.results)
-	cat("\n\n")
-	cat("The global spatial correlation parameter rho is fixed at ", rho,"\n\n", sep="")
-	cat("Acceptance rate for the random effects is ", 100, "%","\n\n", sep="")
-	cat("DIC = ", DIC, "     ", "p.d = ", p.d, "\n")
-	cat("\n")
-	}else
-	{
-	cat("\n#################\n")
-	cat("#### Model fitted\n")
-	cat("#################\n\n")
-	cat("Likelihood model - Gaussian (identity link function) \n")
-	cat("Random effects model - Localised CAR binary weights\n")
-	cat("Regression equation - ")
-	print(formula)
-	cat("Dissimilarity metrics - ")
-	cat(rownames(summary.alpha), sep=", ")
-
-	cat("\n\n############\n")
-	cat("#### Results\n")
-	cat("############\n\n")
-
-	cat("Posterior quantiles and acceptance rates\n\n")
-	print(summary.results)
-	cat("\n\n")
-	cat("Acceptance rate for the random effects is ", 100, "%","\n\n", sep="")
-	cat("DIC = ", DIC, "     ", "p.d = ", p.d, "\n")
-	cat("\n")
-     }
 
 ## Compile and return the results
+model.string <- c("Likelihood model - Gaussian (identity link function)", "\nRandom effects model - Localised CAR", "\nDissimilarity metrics - ", rownames(summary.alpha), "\n")     
+
+     
 	if(fix.rho)
 	{
-	results <- list(formula=formula, samples.beta=samples.beta.orig, samples.phi=mcmc(samples.phi), samples.nu2=mcmc(samples.nu2), samples.tau2=mcmc(samples.tau2), samples.alpha=mcmc(samples.alpha), fitted.values=fitted.values, random.effects=random.effects, W.posterior=W.posterior, W.border.prob=W.border.prob, residuals=residuals, DIC=DIC, p.d=p.d, summary.results=summary.results)
+     samples <- list(beta=samples.beta.orig, phi=mcmc(samples.phi), tau2=mcmc(samples.tau2), nu2=mcmc(samples.nu2), alpha=mcmc(samples.alpha))
+     W.summary <- list(W.posterior=W.posterior, W.border.prob=W.border.prob)
+	results <- list(formula=formula, samples=samples, fitted.values=fitted.values, random.effects=random.effects, residuals=residuals, W.summary=W.summary, DIC=DIC, p.d=p.d, summary.results=summary.results, model=model.string, accept=accept.final)
 	}else
 	{
-	results <- list(formula=formula, samples.beta=samples.beta.orig, samples.phi=mcmc(samples.phi), samples.nu2=mcmc(samples.nu2), samples.tau2=mcmc(samples.tau2), samples.rho=mcmc(samples.rho), samples.alpha=mcmc(samples.alpha), fitted.values=fitted.values, random.effects=random.effects, W.posterior=W.posterior, W.border.prob=W.border.prob, residuals=residuals, DIC=DIC, p.d=p.d, summary.results=summary.results)	}
-
+     samples <- list(beta=samples.beta.orig, phi=mcmc(samples.phi), tau2=mcmc(samples.tau2), nu2=mcmc(samples.nu2), alpha=mcmc(samples.alpha), rho=mcmc(samples.rho))
+     W.summary <- list(W.posterior=W.posterior, W.border.prob=W.border.prob)
+	results <- list(formula=formula, samples=samples,  fitted.values=fitted.values, random.effects=random.effects, residuals=residuals, W.summary=W.summary,  DIC=DIC, p.d=p.d, summary.results=summary.results, model=model.string, accept=accept.final)	
+	}
+class(results) <- "carbayes"
+     
 return(results)
 }
