@@ -1,11 +1,11 @@
 gaussian.independent <-
-function(formula, beta=NULL, theta=NULL, nu2=NULL, sigma2=NULL, burnin=0, n.sample=1000, thin=1, prior.mean.beta=NULL, prior.var.beta=NULL, prior.max.nu2=NULL, prior.max.sigma2=NULL)
+function(formula, data=NULL, beta=NULL, theta=NULL, nu2=NULL, sigma2=NULL, burnin=0, n.sample=1000, thin=1, prior.mean.beta=NULL, prior.var.beta=NULL, prior.max.nu2=NULL, prior.max.sigma2=NULL)
 {
 ##############################################
 #### Format the arguments and check for errors
 ##############################################
 #### Overall formula object
-frame <- try(suppressWarnings(model.frame(formula, na.action=na.pass)), silent=TRUE)
+frame <- try(suppressWarnings(model.frame(formula, data=data, na.action=na.pass)), silent=TRUE)
 if(class(frame)=="try-error") stop("the formula inputted contains an error, e.g the variables may be different lengths.", call.=FALSE)
 
 
@@ -256,7 +256,10 @@ data.temp.beta <- data.var.beta %*% t(X.standardised)
 }
 
 
-
+accept.final <- rep(100, 4)
+names(accept.final) <- c("beta", "theta", "nu2", "sigma")
+     
+     
 ###################################
 #### Summarise and save the results 
 ###################################
@@ -354,28 +357,14 @@ residuals <- round(residuals, 4)
 
      
 
-#### Print a summary of the results to the screen
-cat("\n#################\n")
-cat("#### Model fitted\n")
-cat("#################\n\n")
-cat("Likelihood model - Gaussian (identity link function) \n")
-cat("Random effects model - Independent\n")
-cat("Regression equation - ")
-print(formula)
 
-cat("\n\n############\n")
-cat("#### Results\n")
-cat("############\n\n")
-
-cat("Posterior quantiles and acceptance rates\n\n")
-print(summary.results)
-cat("\n\n")
-cat("Acceptance rate for the random effects is ", 100, "%","\n\n", sep="")
-cat("DIC = ", DIC, "     ", "p.d = ", p.d, "\n")
 
 
 ## Compile and return the results
-results <- list(formula=formula, samples.beta=samples.beta.orig, samples.theta=mcmc(samples.theta), samples.nu2=mcmc(samples.nu2), samples.sigma2=mcmc(samples.sigma2), fitted.values=fitted.values, random.effects=random.effects, residuals=residuals, DIC=DIC, p.d=p.d, summary.results=summary.results)
+model.string <- c("Likelihood model - Gaussian (identity link function)", "\nRandom effects model - Independent\n")     
+samples <- list(beta=samples.beta.orig, theta=mcmc(samples.theta), sigma2=mcmc(samples.sigma2), nu2=mcmc(samples.nu2))
+results <- list(formula=formula, samples=samples, fitted.values=fitted.values, random.effects=random.effects, residuals=residuals, W.summary=NULL, DIC=DIC, p.d=p.d, summary.results=summary.results, model=model.string, accept=accept.final)
+class(results) <- "carbayes"
 return(results)
 }
 
